@@ -1,4 +1,4 @@
-/* $Id: basic.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: basic.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/basic.cc
  *
@@ -38,6 +38,32 @@ const char square_str[][3] = {
 	"a8", "b8", "c8", "d8", "e8", "f8", "g8", "h8"
 };
 
+/*
+ * Create a string with the FEN of the standard opening position.
+ */
+#define WP(p) (std::string(1, (char) toupper(piece_char[p])))
+#define BP(p) (std::string(1, (char) tolower(piece_char[p])))
+std::string opening_fen()
+{
+	std::string fen;
+
+	fen +=    BP(ROOK) + BP(KNIGHT) + BP(BISHOP) + BP(QUEEN)
+		+ BP(KING) + BP(BISHOP) + BP(KNIGHT) + BP(ROOK)
+		+ "/"
+		+ BP(PAWN) + BP(PAWN) + BP(PAWN) + BP(PAWN)
+		+ BP(PAWN) + BP(PAWN) + BP(PAWN) + BP(PAWN)
+		+ "/8/8/8/8/"
+		+ WP(PAWN) + WP(PAWN) + WP(PAWN) + WP(PAWN)
+		+ WP(PAWN) + WP(PAWN) + WP(PAWN) + WP(PAWN)
+		+ "/"
+		+ WP(ROOK) + WP(KNIGHT) + WP(BISHOP) + WP(QUEEN)
+		+ WP(KING) + WP(BISHOP) + WP(KNIGHT) + WP(ROOK)
+		+ " w KQkq - 0 1";
+
+	return fen;
+}
+#undef WP
+#undef BP
 
 /*
  * Initialization function for basic stuff.
