@@ -1,4 +1,4 @@
-/* $Id: board_generate.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: board_generate.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/board_generate.cc
  *
@@ -653,8 +653,8 @@ void Board::add_move(Movelist * movelist, Square from, Square to) const
 		movelist->add(Move::enpassant(from, to));
 	} else if (get_pieces(opponent).testbit(to)) {
 		Piece cap_ptype = piece_at(to);
-		if (ptype == PAWN && (side == WHITE && RNK(to) == RANK8
-				|| side == BLACK && RNK(to) == RANK1)) {
+		if (ptype == PAWN && ((side == WHITE && RNK(to) == RANK8)
+				   || (side == BLACK && RNK(to) == RANK1))) {
 			movelist->add(Move::promotion_capture(from, to, QUEEN,
 						cap_ptype));
 			movelist->add(Move::promotion_capture(from, to, KNIGHT,
@@ -668,8 +668,8 @@ void Board::add_move(Movelist * movelist, Square from, Square to) const
 						cap_ptype));
 		}
 	} else {
-		if (ptype == PAWN && (side == WHITE && RNK(to) == RANK8
-				|| side == BLACK && RNK(to) == RANK1)) {
+		if (ptype == PAWN && ((side == WHITE && RNK(to) == RANK8)
+				   || (side == BLACK && RNK(to) == RANK1))) {
 			movelist->add(Move::promotion(from, to, QUEEN));
 			movelist->add(Move::promotion(from, to, KNIGHT));
 			movelist->add(Move::promotion(from, to, BISHOP));
