@@ -1,4 +1,4 @@
-/* $Id: eval.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: eval.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/chess/eval.cc
  *
@@ -514,16 +514,16 @@ int Evaluator::score_rooks(Color side)
 
 #ifdef EVAL_ROOKINFRONTPP
 			/* Rook in front of passed pawn */
-			if (	side == WHITE && RNK(sq) > RNK(pp)
-			     || side == BLACK && RNK(sq) < RNK(pp)) {
+			if (	(side == WHITE && RNK(sq) > RNK(pp))
+			     || (side == BLACK && RNK(sq) < RNK(pp))) {
 					score += EVAL_ROOKINFRONTPP;
 			}
 #endif
 
 #ifdef EVAL_ROOKBEHINDPP
 			/* Rook behind passed pawn */
-			if (	side == WHITE && RNK(sq) < RNK(pp)
-			     || side == BLACK && RNK(sq) > RNK(pp)) {
+			if (	(side == WHITE && RNK(sq) < RNK(pp))
+			     || (side == BLACK && RNK(sq) > RNK(pp))) {
 					score += EVAL_ROOKBEHINDPP;
 			}
 #endif
