@@ -1,4 +1,4 @@
-/* $Id: move.h 1452 2007-10-30 16:11:59Z holger $
+/* $Id: move.h 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/move.h
  *
@@ -37,7 +37,7 @@ class Board;
 
 class Move {
       public:
-	/* Move flags, we can use a maximum of 14 bits (mov:18-31) */
+	/* Move flags. */
 	enum { MOVE_NONE	= 0x000,
 		MOVE_NORMAL	= 0x001,
 		MOVE_CAPTURE	= 0x002,
@@ -160,8 +160,7 @@ inline Piece Move::ptype() const
 
 inline Piece Move::promote_to() const
 {
-	if (! (flags() & MOVE_PROMOTION))
-		return NO_PIECE;
+	ASSERT_DEBUG(flags() & MOVE_PROMOTION);
 	return ((mov >> 12) & 0x7);
 }
 
