@@ -1,4 +1,4 @@
-/* $Id: pgn.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: pgn.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/pgn.cc
  *
@@ -28,6 +28,7 @@
 
 #include <errno.h>
 #include <stdio.h>
+#include <string.h>
 
 #include <sstream>
 
@@ -119,7 +120,7 @@ bool PGN::parse(FILE * fp)
 			return false;
 		}
 	} else {
-		if (!opening.parse_fen(OPENING_FEN)) {
+		if (!opening.parse_fen(opening_fen())) {
 			BUG("Failed to set up standard opening position");
 		}
 	}
