@@ -1,4 +1,4 @@
-/* $Id: search.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: search.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/search.cc
  *
@@ -260,7 +260,7 @@ void Search::main()
 		iterate();
 	}
 
-	if (verbose || showthinking && !shell->xboard) {
+	if (verbose || (showthinking && !shell->xboard)) {
 		print_statistics();
 		update_overall_statistics();
 		print_overall_statistics();
