@@ -1,4 +1,4 @@
-/* $Id: shell.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: shell.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/shell.cc
  *
@@ -50,7 +50,7 @@ Shell::Shell()
 	myname = PROGNAME + std::string(" ") + VERSION;
 
 	Clock clock(5);
-	game = new Game(OPENING_FEN, clock, clock);	
+	game = new Game(Board(), clock, clock);	
 	book = NULL;
 	hashtable = NULL;
 	pawnhashtable = NULL;
@@ -430,7 +430,7 @@ std::string Shell::get_prompt()
 
 	s += a2;
 	
-	if (flag_analyze || flag_ponder && flag_showthinking) {
+	if (flag_analyze || (flag_ponder && flag_showthinking)) {
 		s += "\n";
 	}
 
