@@ -1,4 +1,4 @@
-/* $Id: shell_cmd.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: shell_cmd.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/shell_cmd.cc
  *
@@ -166,7 +166,7 @@ void Shell::cmd_new()
 {
 	search->stop_thread();
 	
-	if (!game->set_board(OPENING_FEN)) {
+	if (!game->set_board(opening_fen())) {
 		BUG("Failed to set up standard opening position");
 	}
 
@@ -362,7 +362,7 @@ void Shell::cmd_undo()
 {
 	search->stop_thread();
 	if (cmd_args.size() == 2 && cmd_args[1] == "all") {
-		while (game->undo_move());		
+		while (game->undo_move()) {}		
 	} else {
 		if (!game->undo_move()) {
 			if (!xboard) {
