@@ -1,4 +1,4 @@
-/* $Id: basic.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: basic.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/basic.cc
  *
@@ -24,7 +24,11 @@
 #include "common.h"
 #include "basic.h"
 
+#if 0
 const char piece_char[] = { 'P', 'G', 'E', 'N', 'C', 'R', 'K' };
+#else
+const char piece_char[] = { 'P', 'F', 'E', 'N', 'O', 'R', 'K' };
+#endif
 const char file_char[] = { 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i' };
 const char rank_char[] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9' };
 const char square_str[][3] = {
@@ -40,6 +44,46 @@ const char square_str[][3] = {
 	"a9", "b9", "c9", "d9", "e9", "f9", "g9", "h9", "i9",
 };
 
+/*
+ * Create a string with the FEN of the standard opening position.
+ */
+#define WP(p) (std::string(1, (char) toupper(piece_char[p])))
+#define BP(p) (std::string(1, (char) tolower(piece_char[p])))
+#define NP(n) (std::string(1, (char) ('0' + (n))))
+std::string opening_fen()
+{
+	std::string fen;
+
+	fen +=    BP(ROOK) + BP(KNIGHT) + BP(ELEPHANT) + BP(GUARD) + BP(KING)
+		+ BP(GUARD) + BP(ELEPHANT) + BP(KNIGHT) + BP(ROOK)
+		+ "/"
+		+ NP(9)
+		+ "/"
+		+ NP(1) + BP(CANNON) + NP(5) + BP(CANNON) + NP(1)
+		+ "/"
+		+ BP(PAWN) + NP(1) + BP(PAWN) + NP(1) + BP(PAWN) + NP(1)
+		+ BP(PAWN) + NP(1) + BP(PAWN)
+		+ "/"
+		+ NP(9)
+		+ "/"
+		+ NP(9)
+		+ "/"
+		+ WP(PAWN) + NP(1) + WP(PAWN) + NP(1) + WP(PAWN) + NP(1)
+		+ WP(PAWN) + NP(1) + WP(PAWN)
+		+ "/"
+		+ NP(1) + WP(CANNON) + NP(5) + WP(CANNON) + NP(1)
+		+ "/"
+		+ NP(9)
+		+ "/"
+		+ WP(ROOK) + WP(KNIGHT) + WP(ELEPHANT) + WP(GUARD) + WP(KING)
+		+ WP(GUARD) + WP(ELEPHANT) + WP(KNIGHT) + WP(ROOK)
+		+ " w - - 0 1";
+
+	return fen;
+}
+#undef WP
+#undef BP
+#undef NP
 
 /*
  * Initialization function for basic stuff.
