@@ -1,4 +1,4 @@
-/* $Id: basic.h 1452 2007-10-30 16:11:59Z holger $
+/* $Id: basic.h 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/basic.h
  *
@@ -86,6 +86,8 @@ static inline int sq_distance(Square sq1, Square sq2)
 	return abs(RNK(sq1)-RNK(sq2)) + abs(FIL(sq1)-FIL(sq2));
 }
 
+/* FEN of standard opening position. */
+std::string opening_fen();
 
 /*
  * Initialization function for basic stuff.
