@@ -1,4 +1,4 @@
-/* $Id: board.cc 1452 2007-10-30 16:11:59Z holger $
+/* $Id: board.cc 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/board.cc
  *
@@ -31,11 +31,11 @@ Board::Board()
 	clear();
 }
 
-Board::Board(const char * fen)
+Board::Board(const std::string& fen)
 {
 	clear();
 	if (!parse_fen(fen)) {
-		BUG("Constructor called with illegal FEN: %s", fen);
+		BUG("Constructor called with illegal FEN: %s", fen.c_str());
 	}
 }
 
@@ -112,7 +112,7 @@ void Board::make_move(Move mov)
 #ifdef USE_UNMAKE_MOVE
 	hist.movecnt50 = movecnt50;
 #endif
-	if (mov.ptype() == PAWN && RNK(mov.from()) != RNK(mov.to())
+	if ((mov.ptype() == PAWN && RNK(mov.from()) != RNK(mov.to()))
 			|| mov.is_capture()) {
 		movecnt50 = 0;
 	} else {
