@@ -1,4 +1,4 @@
-/* $Id: board.h 1452 2007-10-30 16:11:59Z holger $
+/* $Id: board.h 1462 2007-12-18 20:49:56Z holger $
  *
  * HoiChess/board.h
  *
@@ -65,7 +65,7 @@ class Board
 	/* Constructors / Destructor, defined in board.cc */
       public:
 	Board();
-	Board(const char * fen);
+	Board(const std::string& fen);
 	inline ~Board() {};
 	
 	/* Accessors */
